package com.zd.exam.mapper;

import java.util.List;

import com.zd.exam.domain.ElExamClassify;

/**
 * 题目类型Mapper接口
 *
 * @author liubo
 * @date 2021-12-09
 */
public interface ElExamClassifyMapper {
    /**
     * 查询题目类型
     *
     * @param id 题目类型主键
     * @return 题目类型
     */
    public ElExamClassify selectElExamClassifyById(Long id);

    /**
     * 查询题目类型列表
     *
     * @param elExamClassify 题目类型
     * @return 题目类型集合
     */
    public List<ElExamClassify> selectElExamClassifyList(ElExamClassify elExamClassify);

    /**
     * 新增题目类型
     *
     * @param elExamClassify 题目类型
     * @return 结果
     */
    public int insertElExamClassify(ElExamClassify elExamClassify);

    /**
     * 修改题目类型
     *
     * @param elExamClassify 题目类型
     * @return 结果
     */
    public int updateElExamClassify(ElExamClassify elExamClassify);

    /**
     * 删除题目类型
     *
     * @param id 题目类型主键
     * @return 结果
     */
    public int deleteElExamClassifyById(Long id);

    /**
     * 批量删除题目类型
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElExamClassifyByIds(Long[] ids);

    String queryTitleyByIds(String ids);
}
